==> politicsnlp-0.0.19-py3-none-any.whl: politicsnlp/__init__.py <==
# ----------------------------------- Core --------------------------------------------------- #
from politicsnlp.core.justice import *
from politicsnlp.core.freedom import *
from politicsnlp.core.democracy import *
from politicsnlp.core.spirit_of_the_law import *
from politicsnlp.core.separation_of_powers import *
from politicsnlp.core.natural_rights import *
# ----------------------------------- Diplomacy --------------------------------------------------- #
from politicsnlp.diplomacy.hegemony import *
from politicsnlp.diplomacy.coercive_diplomacy import *
from politicsnlp.diplomacy.wolf_warrior_diplomacy import *
# ----------------------------------- Form Of Government --------------------------------------------------- #
from politicsnlp.form_of_government.regime import *
from politicsnlp.form_of_government.aristocracy import *
from politicsnlp.form_of_government.autocracy import *
from politicsnlp.form_of_government.socialism import *
from politicsnlp.form_of_government.colonialism import *
from politicsnlp.form_of_government.communism import *
from politicsnlp.form_of_government.direct_democracy import *
from politicsnlp.form_of_government.representative_democracy import *
from politicsnlp.form_of_government.direct_democracy import *
from politicsnlp.form_of_government.oligarchy import *
from politicsnlp.form_of_government.monarchy import *
from politicsnlp.form_of_government.theocracy import *
# ----------------------------------- Ideology --------------------------------------------------- #
from politicsnlp.ideology.ideology import *
from politicsnlp.ideology.nationalism import *
from politicsnlp.ideology.confucianism import *
from politicsnlp.ideology.liberalism import *
from politicsnlp.ideology.populism import *
# ----------------------------------- Individual --------------------------------------------------- #
from politicsnlp.individual.individual import *
from politicsnlp.individual.strongman import *
from politicsnlp.individual.monarch import *
from politicsnlp.individual.tyrant import *
from politicsnlp.individual.civil_servant import *
# ----------------------------------- Institutions --------------------------------------------------- #
# ----------------- Legislative Institutions ------------------------- #
from politicsnlp.institutions.legislative_institutions.legislature import *
# ----------------- Administrative Institutions ------------------------- #
from politicsnlp.institutions.administrative_institutions.administration import *
# ----------------- Judicial Institutions ------------------------- #
from politicsnlp.institutions.judicial_institutions.judiciary import *
from politicsnlp.institutions.legislative_institutions.peoples_congress_system import *

# ----------------------------------- Marxism --------------------------------------------------- #
from politicsnlp.marxism.marxism import *
from politicsnlp.marxism.mao_ze_dong_thought import *
from politicsnlp.marxism.deng_xiao_ping_theory import *
from politicsnlp.marxism.xi_jin_ping_thought import *
from politicsnlp.marxism.people_democracy import *
from politicsnlp.marxism.public_ownership import *
from politicsnlp.marxism.distribution_according_to_work import *
from politicsnlp.marxism.surplus_value import *
# ----------------------------------- Organisation --------------------------------------------------- #
from politicsnlp.organisation.NATO import *
# ----------------------------------- Party --------------------------------------------------- #
from politicsnlp.party.UKIP import *
from politicsnlp.party.conservative_party import *
from politicsnlp.party.CCP import *
from politicsnlp.party.DPP import *
# ----------------------------------- Power --------------------------------------------------- #
from politicsnlp.power.discourse_power import *
from politicsnlp.power.power import *
# ----------------------------------- People --------------------------------------------------- #
from politicsnlp.people.person import *
from politicsnlp.people.masses import *
from politicsnlp.people.people import *
from politicsnlp.people.crowd import *
from politicsnlp.people.pink_youth import *
from politicsnlp.people.red_generation import *
from politicsnlp.people.political_elites import *
from politicsnlp.people.refugee import *
from politicsnlp.people.political_community import *
from politicsnlp.people.nationalist import *
from politicsnlp.people.populist import *
# ----------------------------------- Philosophy --------------------------------------------------- #
from politicsnlp.philosophy.idealstate import *
# ----------------------------------- Stance --------------------------------------------------- #
from politicsnlp.stance.hawk import *
from politicsnlp.stance.leftist import *
from politicsnlp.stance.rightist import *
from politicsnlp.stance.neutral import *
# ----------------------------------- Uprisings and Protests --------------------------------------------------- #
from politicsnlp.uprisings_and_protests.jasmine_revolution import *
from politicsnlp.uprisings_and_protests.arab_spring import *
from politicsnlp.uprisings_and_protests.blank_revolution import *
from politicsnlp.uprisings_and_protests.tiananmen_square_incident import *


from politicsnlp.authoritarianism import *
from politicsnlp.government import *
from politicsnlp.dictatorship import *
from politicsnlp.protection import *
from politicsnlp.revolution import *
from politicsnlp.sanctions import *
from politicsnlp.the_tyranny_of_the_majority import *
from politicsnlp.social_contract import *
from politicsnlp.limited_power import *
from politicsnlp.territory import *
from politicsnlp.centralization import *
from politicsnlp.political_movement import *
from politicsnlp.intelligence import *
from politicsnlp.tense_air import *
from politicsnlp.purges import *
from politicsnlp.information_literacy import *
from politicsnlp.false_flag_operation import *
from politicsnlp.orientalism import *
from politicsnlp.de_orientalizing import *
from politicsnlp.eurosceptics import *
from politicsnlp.military_coup import *
from politicsnlp.national_interest import *
from politicsnlp.tense_air import *

==> politicsnlp-0.0.21-py3-none-any.whl: politicsnlp/__init__.py <==


# ----------------------------------- Diplomacy --------------------------------------------------- #
from politicsnlp.diplomacy.hegemony import *
from politicsnlp.diplomacy.coercive_diplomacy import *
from politicsnlp.diplomacy.wolf_warrior_diplomacy import *
# ----------------------------------- Form Of Government --------------------------------------------------- #
from politicsnlp.form_of_government.regime import *
from politicsnlp.form_of_government.aristocracy import *
from politicsnlp.form_of_government.autocracy import *
from politicsnlp.form_of_government.socialism import *
from politicsnlp.form_of_government.colonialism import *
from politicsnlp.form_of_government.communism import *
from politicsnlp.form_of_government.direct_democracy import *
from politicsnlp.form_of_government.representative_democracy import *
from politicsnlp.form_of_government.direct_democracy import *
from politicsnlp.form_of_government.oligarchy import *
from politicsnlp.form_of_government.monarchy import *
from politicsnlp.form_of_government.theocracy import *
# ----------------------------------- Ideology --------------------------------------------------- #
from politicsnlp.ideology.ideology import *
from politicsnlp.ideology.nationalism import *
from politicsnlp.ideology.confucianism import *
from politicsnlp.ideology.liberalism import *
from politicsnlp.ideology.populism import *
from politicsnlp.ideology.green_politics import *
from politicsnlp.ideology.economic_liberalism import *


# ----------------------------------- Individual --------------------------------------------------- #
from politicsnlp.individual.individual import *
from politicsnlp.individual.strongman import *
from politicsnlp.individual.monarch import *
from politicsnlp.individual.tyrant import *
from politicsnlp.individual.civil_servant import *
# ----------------------------------- Institutions --------------------------------------------------- #
# ----------------- Legislative Institutions ------------------------- #
from politicsnlp.institutions.legislative_institutions.legislature import *
# ----------------- Administrative Institutions ------------------------- #
from politicsnlp.institutions.administrative_institutions.administration import *
from politicsnlp.institutions.administrative_institutions.bureaucracy import *

# ----------------- Judicial Institutions ------------------------- #
from politicsnlp.institutions.judicial_institutions.judiciary import *
from politicsnlp.institutions.legislative_institutions.peoples_congress_system import *

# ----------------------------------- Marxism --------------------------------------------------- #
from politicsnlp.marxism.marxism import *
from politicsnlp.marxism.mao_ze_dong_thought import *
from politicsnlp.marxism.deng_xiao_ping_theory import *
from politicsnlp.marxism.xi_jin_ping_thought import *
from politicsnlp.marxism.people_democracy import *
from politicsnlp.marxism.public_ownership import *
from politicsnlp.marxism.distribution_according_to_work import *
from politicsnlp.marxism.surplus_value import *
from politicsnlp.marxism.common_front import *
# ----------------------------------- Movement --------------------------------------------------- #

from politicsnlp.movement.political_movement import *
from politicsnlp.movement.political_movement import *

# ----------------------------------- Organisation --------------------------------------------------- #
from politicsnlp.organisation.NATO import *
# ----------------------------------- Party --------------------------------------------------- #
from politicsnlp.party.UKIP import *
from politicsnlp.party.conservative_party import *
from politicsnlp.party.CCP import *
from politicsnlp.party.DPP import *
# ----------------------------------- Power --------------------------------------------------- #
from politicsnlp.power.discourse_power import *
from politicsnlp.power.power import *
# ----------------------------------- People --------------------------------------------------- #
from politicsnlp.people.person import *
from politicsnlp.people.masses import *
from politicsnlp.people.people import *
from politicsnlp.people.crowd import *
from politicsnlp.people.pink_youth import *
from politicsnlp.people.red_generation import *
from politicsnlp.people.political_elites import *
from politicsnlp.people.refugee import *
from politicsnlp.people.political_community import *
from politicsnlp.people.nationalist import *
from politicsnlp.people.populist import *
from politicsnlp.people.internal_enemy import *
from politicsnlp.people.eurosceptics import *

# ----------------------------------- Philosophy and Idea --------------------------------------------------- #
from politicsnlp.philosophy_idea.idealstate import *
from politicsnlp.philosophy_idea.globalism import *
from politicsnlp.philosophy_idea.orientalism import *

# ----------------------------------- Principle --------------------------------------------------- #
from politicsnlp.principle.justice import *
from politicsnlp.principle.freedom import *
from politicsnlp.principle.democracy import *
from politicsnlp.principle.spirit_of_the_law import *
from politicsnlp.principle.separation_of_powers import *
from politicsnlp.principle.natural_rights import *
from politicsnlp.principle.freedom_of_speech import *
from politicsnlp.principle.popular_sovereignty import *
from politicsnlp.principle.harm_principle import *

# ----------------------------------- Stance --------------------------------------------------- #


# ----------------------------------- Stance --------------------------------------------------- #
from politicsnlp.stance.hawk import *
from politicsnlp.stance.leftist import *
from politicsnlp.stance.rightist import *
from politicsnlp.stance.neutral import *
# ----------------------------------- Uprisings and Protests --------------------------------------------------- #
from politicsnlp.uprisings_and_protests.jasmine_revolution import *
from politicsnlp.uprisings_and_protests.arab_spring import *
from politicsnlp.uprisings_and_protests.blank_revolution import *
from politicsnlp.uprisings_and_protests.tiananmen_square_incident import *
from politicsnlp.uprisings_and_protests.protest import *


from politicsnlp.authoritarianism import *
from politicsnlp.government import *
from politicsnlp.dictatorship import *
from politicsnlp.protection import *
from politicsnlp.revolution import *
from politicsnlp.sanctions import *
from politicsnlp.the_tyranny_of_the_majority import *
from politicsnlp.social_contract import *
from politicsnlp.limited_power import *
from politicsnlp.territory import *
from politicsnlp.centralization import *
from politicsnlp.intelligence import *
from politicsnlp.tense_air import *
from politicsnlp.purges import *
from politicsnlp.information_literacy import *
from politicsnlp.false_flag_operation import *
from politicsnlp.de_orientalizing import *
from politicsnlp.military_coup import *
from politicsnlp.national_interest import *
from politicsnlp.hate_speech import *
from politicsnlp.rhetoric import *
